@@ -22,7 +22,5 @@ SOFTWARE."""
 
 from .aioclient import WaifuAioClient
 from .exceptions import *
-from .utils import requires_token,APIBaseURL
-
-__author__ = 'Buco'
-__version__ = '2.4.1'
+from .utils import requires_token, APIBaseURL
+from .moduleinfo import *
\ No newline at end of file
